remove hacks to disable math or LDG functions.
Этот коммит содержится в:
@@ -21,7 +21,6 @@ THE SOFTWARE.
|
||||
#define HIP_LDG_H
|
||||
|
||||
#if __HCC__
|
||||
#if defined (USE_LDG)
|
||||
#include"hip_vector_types.h"
|
||||
#include"host_defines.h"
|
||||
#if __hcc_workweek__ >= 16164
|
||||
@@ -100,8 +99,6 @@ __device__ double4 __ldg(const double4* );
|
||||
|
||||
#endif // __hcc_workweek__
|
||||
|
||||
#endif // USE_LDG
|
||||
|
||||
#endif // __HCC__
|
||||
|
||||
#endif // HIP_LDG_H
|
||||
|
||||
@@ -109,7 +109,6 @@ extern int HIP_TRACE_API;
|
||||
#define __HCC_C__
|
||||
#endif
|
||||
|
||||
#ifdef DISABLED_MATH_FUNC // TODO - remove this flag.
|
||||
__device__ float acosf(float x);
|
||||
__device__ float acoshf(float x);
|
||||
__device__ float asinf(float x);
|
||||
@@ -442,7 +441,6 @@ __device__ float __dsqrt_rd(double x);
|
||||
__device__ float __dsqrt_rn(double x);
|
||||
__device__ float __dsqrt_ru(double x);
|
||||
__device__ float __dsqrt_rz(double x);
|
||||
#endif /* DISABLED_MATH_FUNC*/
|
||||
/**
|
||||
* Kernel launching
|
||||
*/
|
||||
|
||||
@@ -20,7 +20,7 @@ THE SOFTWARE.
|
||||
#include <hc.hpp>
|
||||
#include"hcc_detail/hip_ldg.h"
|
||||
|
||||
#if __hcc_workweek__ >= 16164 and defined (USE_LDG)
|
||||
#if __hcc_workweek__ >= 16164
|
||||
__device__ char __ldg(const char* ptr)
|
||||
{
|
||||
return ptr[0];
|
||||
|
||||
Ссылка в новой задаче
Block a user